---
title: Admonitions
---

The Admonition extension adds rST-style admonitions to Markdown documents.

    :::md {.light}
    !!! info "Information:"
        Something **new** is coming

    !!! note "Note:"
        We notice that

    !!! warning "Warning:"
        There is a *risk* doing that

    !!! danger "Danger:"
        Don't do that please!

!!! info "Info:"
    Something **new** is coming

!!! note "Note:"
    We notice that

!!! warning "Warning:"
    There is a *risk* doing that

!!! danger "Danger:"
    Don't do that please!